"use strict";
/**
 *
 * Wechaty: Wechat for Bot. and for human who talk to bot/robot
 *
 * Class StateSwitch
 * Licenst: Apache-2.0
 * https://github.com/zixia/state-switcher
 *
 * Helper Class for Manage State Change
 */
Object.defineProperty(exports, "__esModule", { value: true });
class StateSwitch {
    constructor(_name = 'Lock', logInstance) {
        this._name = _name;
        if (logInstance) {
            this.setLog(logInstance); // init log, should be a Brolog or Npmlog instance
        }
        else {
            this.setLog(null);
        }
        this.log.silly('StateSwitch', 'constructor(%s)', _name);
        this._on = false;
        this._pending = false;
    }
    setLog(logInstance) {
        if (logInstance) {
            this.log = logInstance;
        }
        else {
            this.log = {
                silly(...args) { },
                verbose(...args) { },
                warn(...args) { },
                error(...args) { },
            };
        }
    }
    /**
     * set/get ON state
     */
    on(state) {
        if (state) {
            this.log.verbose('StateSwitch', '<%s> on(%s) <- (%s)', this._name, state, this.on());
            this._on = true;
            this._pending = (state === 'pending');
            return;
        }
        const on = this._on
            ? this._pending ? 'pending' : true
            : false;
        this.log.silly('StateSwitch', '<%s> on() is %s', this._name, on);
        return on;
    }
    /**
     * set/get OFF state
     */
    off(state) {
        if (state) {
            this.log.verbose('StateSwitch', '<%s> off(%s) <- (%s)', this._name, state, this.off());
            this._on = false;
            this._pending = (state === 'pending');
            return;
        }
        const off = !this._on
            ? this._pending ? 'pending' : true
            : false;
        this.log.silly('StateSwitch', '<%s> off() is %s', this._name, off);
        return off;
    }
    /**
     * does the state is not stable(in process)?
     */
    pending() {
        this.log.silly('StateSwitch', '<%s> pending() is %s', this._name, this._pending);
        return this._pending;
    }
    /**
     * get the client name
     */
    name() {
        return this._name;
    }
}
exports.StateSwitch = StateSwitch;
exports.default = StateSwitch;
//# sourceMappingURL=state-switch.js.map